@@ -36,7 +36,7 @@
  * @author    Michael Gauthier <mike@silverorange.com>
  * @copyright 2005-2008 silverorange
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
- * @version   CVS: $Id: SignTestCase.php,v 1.4 2008/10/14 00:05:00 gauthierm Exp $
+ * @version   CVS: $Id: SignTestCase.php 295623 2010-03-01 04:35:47Z gauthierm $
  * @link      http://pear.php.net/package/Crypt_GPG
  */
 
@@ -295,6 +295,48 @@ class SignTestCase extends Crypt_GPG_TestCase
         }
     }
 
+    // }}}
+    // {{{ testSignDetachedTextmode()
+
+    /**
+     * @group string
+     */
+    public function testSignDetachedTextmode()
+    {
+        // data with Unix line endings
+        $data = "It was the best of times,\n"
+            . "it was the worst of times,\n"
+            . "it was the age of wisdom,\n"
+            . "it was the age of foolishness,\n"
+            . "it was the epoch of belief,\n"
+            . "it was the epoch of incredulity,\n"
+            . "it was the season of Light,\n"
+            . "it was the season of Darkness,\n"
+            . "it was the spring of hope,\n"
+            . "it was the winter of despair,";
+
+        $this->gpg->addSignKey('first-keypair@example.com', 'test1');
+        $signatureData = $this->gpg->sign(
+            $data,
+            Crypt_GPG::SIGN_MODE_DETACHED,
+            true,
+            true
+        );
+
+        // convert data to Windows line endings
+        $data = str_replace("\n", "\r\n", $data);
+
+        // verify data
+        $signatures = $this->gpg->verify($data, $signatureData);
+        $this->assertEquals(1, count($signatures));
+        foreach ($signatures as $signature) {
+            $this->assertTrue(
+                $signature->isValid(),
+                'Failed asserting textmode signature is valid.'
+            );
+        }
+    }
+
     // }}}
 
     // file
@@ -531,7 +573,7 @@ class SignTestCase extends Crypt_GPG_TestCase
     {
         // input file is encrypted with first-keypair@example.com
         // output file does not exist
-        $inputFilename  = $this->getDataFilename('testMediumFile.plain');
+        $inputFilename  = $this->getDataFilename('testFileMedium.plain');
         $outputFilename = './non-existent' .
             '/testSignFileFileException_output.plain';
 
